@@ -1,20 +1,21 @@
 from .abstracts import (
     AbstractParser,
     BaseStorage,
+    AbstractPaymentWrapper,
     AioTestCase
 )
-from .aiohttp_custom_api import RequestManager
-from .basic_requests_api import HttpXParser
-from .core_mixins import BillMixin, ToolsMixin
-from .storage import Storage
+from .aiohttp_custom_api import CustomParser
+from .basic_requests_api import HttpXParser, Storage
+from .mixins import BillMixin, ToolsMixin
 
 __all__ = (
     'HttpXParser',
     'Storage',
     'AbstractParser',
+    'AbstractPaymentWrapper',
     'BaseStorage',
     'AioTestCase',
     'BillMixin',
     'ToolsMixin',
-    'RequestManager'
+    'CustomParser'
 )
