@@ -1,3 +1,4 @@
+from datetime import datetime
 from typing import Optional, List
 
 from pydantic import Field, BaseModel
@@ -13,7 +14,9 @@ class PassInfo(BaseModel):
 
 
 class MobilePinInfo(BaseModel):
-    last_mobile_pin_change: Optional[str] = Field(alias="lastMobilePinChange")
+    last_mobile_pin_change: Optional[
+        datetime
+    ] = Field(alias="lastMobilePinChange")
     mobile_pin_used: bool = Field(alias="mobilePinUsed")
     next_mobile_pin_change: str = Field(alias="nextMobilePinChange")
 
@@ -25,20 +28,22 @@ class PinInfo(BaseModel):
 class AuthInfo(BaseModel):
     ip: str
     bound_email: Optional[str] = Field(alias="boundEmail", const=None)
-    last_login_date: Optional[str] = Field(alias="lastLoginDate", const=None)
+    last_login_date: Optional[
+        datetime
+    ] = Field(alias="lastLoginDate", const=None)
     email_settings: Optional[dict] = Field(alias="emailSettings", const=None)
     mobile_pin_info: MobilePinInfo = Field(alias="mobilePinInfo")
     pass_info: PassInfo = Field(alias="passInfo")
     person_id: int = Field(alias="personId")
     pin_info: PinInfo = Field(alias="pinInfo")
-    registration_date: str = Field(alias="registrationDate")
+    registration_date: datetime = Field(alias="registrationDate")
 
 
 class SmsNotification(BaseModel):
     price: Sum
     enabled: bool
     active: bool
-    end_date: Optional[str] = Field(alias="endDate", const=None)
+    end_date: Optional[datetime] = Field(alias="endDate", const=None)
 
 
 class IdentificationInfo(BaseModel):
@@ -64,8 +69,10 @@ class Feature(BaseModel):
 class ContractInfo(BaseModel):
     blocked: bool = False
     contract_id: int = Field(alias="contractId")
-    creation_date: str = Field(alias="creationDate")
-    identification_info: List[IdentificationInfo] = Field(alias="identificationInfo")
+    creation_date: datetime = Field(alias="creationDate")
+    identification_info: List[
+        IdentificationInfo
+    ] = Field(alias="identificationInfo")
     sms_notification: SmsNotification = Field(alias="smsNotification")
     nickname: NickName
     features: Optional[List[Feature]] = None
@@ -74,24 +81,40 @@ class ContractInfo(BaseModel):
 
 class UserInfo(BaseModel):
     default_pay_currency: str = Field(alias="defaultPayCurrency")
-    default_pay_source: Optional[int] = Field(alias="defaultPaySource", const=None)
-    default_pay_account_alias: Optional[str] = Field(alias="defaultPayAccountAlias", const=None)
+    default_pay_source: Optional[
+        int
+    ] = Field(alias="defaultPaySource", const=None)
+    default_pay_account_alias: Optional[
+        str
+    ] = Field(alias="defaultPayAccountAlias", const=None)
     email: Optional[str] = None
     first_transaction_id: int = Field(alias="firstTxnId")
     language: str
     operator: str
     phone_hash: str = Field(alias="phoneHash")
-    promo_enabled: Optional[bool] = Field(alias="promoEnabled", const=None)
+    promo_enabled: Optional[
+        bool
+    ] = Field(alias="promoEnabled", const=None)
 
 
 class QiwiAccountInfo(BaseModel):
+    """Информация об аккаунте"""
     auth_info: Optional[AuthInfo] = Field(alias="authInfo", const=None)
-    contract_info: Optional[ContractInfo] = Field(alias="contractInfo", const=None)
+    contract_info: Optional[
+        ContractInfo
+    ] = Field(alias="contractInfo", const=None)
     user_info: Optional[UserInfo] = Field(alias="userInfo", const=None)
 
     class Config:
+        """ Pydantic config """
         json_loads = custom_load
 
+        def __str__(self) -> str:
+            return f'Config class with loads={self.json_loads}'
+
+        def __repr__(self) -> str:
+            return self.__str__()
+
 
 __all__ = [
     'QiwiAccountInfo'
