@@ -1,3 +1,4 @@
+from datetime import datetime
 from typing import Union
 
 from pydantic import BaseModel, Field
@@ -6,8 +7,8 @@ from glQiwiApi.utils.basics import custom_load
 
 
 class Interval(BaseModel):
-    date_from: str = Field(alias="dateFrom")
-    date_till: str = Field(alias="dateTill")
+    date_from: datetime = Field(alias="dateFrom")
+    date_till: datetime = Field(alias="dateTill")
 
 
 class Limit(BaseModel):
@@ -19,8 +20,15 @@ class Limit(BaseModel):
     limit_type: str = Field(alias="type")
 
     class Config:
+        """ Pydantic config """
         json_loads = custom_load
 
+        def __str__(self) -> str:
+            return f'Config class with loads={self.json_loads}'
+
+        def __repr__(self) -> str:
+            return self.__str__()
+
 
 __all__ = [
     'Limit'
